@@ -4,7 +4,7 @@ package Mail::Toaster::Utility;
 use strict;
 use warnings;
 
-our $VERSION = '5.50';
+our $VERSION = '5.51';
 
 use Cwd;
 use Carp;
@@ -1844,27 +1844,6 @@ sub mkdir_system {
     return $self->error( '', %args );
 }
 
-sub path_parse {
-    my $self = shift;
-    my $dir = shift or die "missing dir!";
-    # code left here for reference, use File::Basename instead
-
-    # if it ends with a /, chop if off
-    if ( $dir =~ q{/$} ) { chop $dir }
-
-    # get the position of the last / in the path
-    my $rindex = rindex( $dir, "/" );
-
-    # grabs everything up to the last /
-    my $updir = substr( $dir, 0, $rindex );
-    $rindex++;
-
-    # matches from the last / char +1 to the end of string
-    my $curdir = substr( $dir, $rindex );
-
-    return $updir, $curdir;
-}
-
 sub check_pidfile {
     my $self = shift;
     my $file = shift;
@@ -2678,7 +2657,7 @@ Check all the "normal" locations for a binary that should be on the system and r
 
 Example:
 
-   my $apachectl = $util->find_bin( "apachectl", dir=>"/usr/local/sbin" );
+   my $sudo = $util->find_bin( "sudo", dir => "/usr/local/sbin" );
 
 
  arguments required:
